@@ -87,29 +87,14 @@ var _ = DescribeTable("Create", func(t ngEntry) {
 		expErr: errors.Wrapf(errors.New("VPC configuration required for creating nodegroups on clusters not owned by eksctl: vpc.subnets, vpc.id, vpc.securityGroup"), "loading VPC spec for cluster %q", "my-cluster"),
 	}),
 
-	Entry("fails when cluster does not support managed nodes", ngEntry{
-		mockCalls: func(k *fakes.FakeKubeProvider, init *fakes.FakeNodeGroupInitialiser, f *utilFakes.FakeNodegroupFilter) {
-			k.SupportsManagedNodesReturns(false, errors.New("err"))
-		},
-		expectedCalls: func(k *fakes.FakeKubeProvider, _ *fakes.FakeNodeGroupInitialiser, _ *utilFakes.FakeNodegroupFilter) {
-			Expect(k.NewRawClientCallCount()).To(Equal(1))
-			Expect(k.ServerVersionCallCount()).To(Equal(1))
-			Expect(k.LoadClusterIntoSpecFromStackCallCount()).To(Equal(1))
-			Expect(k.SupportsManagedNodesCallCount()).To(Equal(1))
-		},
-		expErr: errors.New("err"),
-	}),
-
 	Entry("fails to set instance types to instances matched by instance selector criteria", ngEntry{
 		mockCalls: func(k *fakes.FakeKubeProvider, init *fakes.FakeNodeGroupInitialiser, f *utilFakes.FakeNodegroupFilter) {
-			k.SupportsManagedNodesReturns(true, nil)
 			init.ExpandInstanceSelectorOptionsReturns(errors.New("err"))
 		},
 		expectedCalls: func(k *fakes.FakeKubeProvider, init *fakes.FakeNodeGroupInitialiser, _ *utilFakes.FakeNodegroupFilter) {
 			Expect(k.NewRawClientCallCount()).To(Equal(1))
 			Expect(k.ServerVersionCallCount()).To(Equal(1))
 			Expect(k.LoadClusterIntoSpecFromStackCallCount()).To(Equal(1))
-			Expect(k.SupportsManagedNodesCallCount()).To(Equal(1))
 			Expect(init.NewAWSSelectorSessionCallCount()).To(Equal(1))
 			Expect(init.ExpandInstanceSelectorOptionsCallCount()).To(Equal(1))
 		},
@@ -118,14 +103,12 @@ var _ = DescribeTable("Create", func(t ngEntry) {
 
 	Entry("fails when cluster is not compatible with ng config", ngEntry{
 		mockCalls: func(k *fakes.FakeKubeProvider, init *fakes.FakeNodeGroupInitialiser, f *utilFakes.FakeNodegroupFilter) {
-			k.SupportsManagedNodesReturns(true, nil)
 			k.ValidateClusterForCompatibilityReturns(errors.New("err"))
 		},
 		expectedCalls: func(k *fakes.FakeKubeProvider, init *fakes.FakeNodeGroupInitialiser, _ *utilFakes.FakeNodegroupFilter) {
 			Expect(k.NewRawClientCallCount()).To(Equal(1))
 			Expect(k.ServerVersionCallCount()).To(Equal(1))
 			Expect(k.LoadClusterIntoSpecFromStackCallCount()).To(Equal(1))
-			Expect(k.SupportsManagedNodesCallCount()).To(Equal(1))
 			Expect(init.NewAWSSelectorSessionCallCount()).To(Equal(1))
 			Expect(init.ExpandInstanceSelectorOptionsCallCount()).To(Equal(1))
 			Expect(k.ValidateClusterForCompatibilityCallCount()).To(Equal(1))
@@ -135,14 +118,12 @@ var _ = DescribeTable("Create", func(t ngEntry) {
 
 	Entry("fails when it cannot validate legacy subnets for ng", ngEntry{
 		mockCalls: func(k *fakes.FakeKubeProvider, init *fakes.FakeNodeGroupInitialiser, f *utilFakes.FakeNodegroupFilter) {
-			k.SupportsManagedNodesReturns(true, nil)
 			init.ValidateLegacySubnetsForNodeGroupsReturns(errors.New("err"))
 		},
 		expectedCalls: func(k *fakes.FakeKubeProvider, init *fakes.FakeNodeGroupInitialiser, _ *utilFakes.FakeNodegroupFilter) {
 			Expect(k.NewRawClientCallCount()).To(Equal(1))
 			Expect(k.ServerVersionCallCount()).To(Equal(1))
 			Expect(k.LoadClusterIntoSpecFromStackCallCount()).To(Equal(1))
-			Expect(k.SupportsManagedNodesCallCount()).To(Equal(1))
 			Expect(init.NewAWSSelectorSessionCallCount()).To(Equal(1))
 			Expect(init.ExpandInstanceSelectorOptionsCallCount()).To(Equal(1))
 			Expect(k.ValidateClusterForCompatibilityCallCount()).To(Equal(1))
@@ -153,14 +134,12 @@ var _ = DescribeTable("Create", func(t ngEntry) {
 
 	Entry("fails when existing local ng stacks in config file is not listed", ngEntry{
 		mockCalls: func(k *fakes.FakeKubeProvider, init *fakes.FakeNodeGroupInitialiser, f *utilFakes.FakeNodegroupFilter) {
-			k.SupportsManagedNodesReturns(true, nil)
 			f.SetOnlyLocalReturns(errors.New("err"))
 		},
 		expectedCalls: func(k *fakes.FakeKubeProvider, init *fakes.FakeNodeGroupInitialiser, f *utilFakes.FakeNodegroupFilter) {
 			Expect(k.NewRawClientCallCount()).To(Equal(1))
 			Expect(k.ServerVersionCallCount()).To(Equal(1))
 			Expect(k.LoadClusterIntoSpecFromStackCallCount()).To(Equal(1))
-			Expect(k.SupportsManagedNodesCallCount()).To(Equal(1))
 			Expect(init.NewAWSSelectorSessionCallCount()).To(Equal(1))
 			Expect(init.ExpandInstanceSelectorOptionsCallCount()).To(Equal(1))
 			Expect(k.ValidateClusterForCompatibilityCallCount()).To(Equal(1))
@@ -171,14 +150,12 @@ var _ = DescribeTable("Create", func(t ngEntry) {
 
 	Entry("fails to evaluate whether aws-node uses IRSA", ngEntry{
 		mockCalls: func(k *fakes.FakeKubeProvider, init *fakes.FakeNodeGroupInitialiser, f *utilFakes.FakeNodegroupFilter) {
-			k.SupportsManagedNodesReturns(true, nil)
 			init.DoesAWSNodeUseIRSAReturns(true, errors.New("err"))
 		},
 		expectedCalls: func(k *fakes.FakeKubeProvider, init *fakes.FakeNodeGroupInitialiser, f *utilFakes.FakeNodegroupFilter) {
 			Expect(k.NewRawClientCallCount()).To(Equal(1))
 			Expect(k.ServerVersionCallCount()).To(Equal(1))
 			Expect(k.LoadClusterIntoSpecFromStackCallCount()).To(Equal(1))
-			Expect(k.SupportsManagedNodesCallCount()).To(Equal(1))
 			Expect(init.NewAWSSelectorSessionCallCount()).To(Equal(1))
 			Expect(init.ExpandInstanceSelectorOptionsCallCount()).To(Equal(1))
 			Expect(k.ValidateClusterForCompatibilityCallCount()).To(Equal(1))
@@ -191,14 +168,12 @@ var _ = DescribeTable("Create", func(t ngEntry) {
 	Entry("stack manager fails to do ng tasks", ngEntry{
 		mockCalls: func(k *fakes.FakeKubeProvider, init *fakes.FakeNodeGroupInitialiser, f *utilFakes.FakeNodegroupFilter) {
 			k.NewRawClientReturns(&kubernetes.RawClient{}, nil)
-			k.SupportsManagedNodesReturns(true, nil)
 			init.DoAllNodegroupStackTasksReturns(errors.New("err"))
 		},
 		expectedCalls: func(k *fakes.FakeKubeProvider, init *fakes.FakeNodeGroupInitialiser, f *utilFakes.FakeNodegroupFilter) {
 			Expect(k.NewRawClientCallCount()).To(Equal(1))
 			Expect(k.ServerVersionCallCount()).To(Equal(1))
 			Expect(k.LoadClusterIntoSpecFromStackCallCount()).To(Equal(1))
-			Expect(k.SupportsManagedNodesCallCount()).To(Equal(1))
 			Expect(init.NewAWSSelectorSessionCallCount()).To(Equal(1))
 			Expect(init.ExpandInstanceSelectorOptionsCallCount()).To(Equal(1))
 			Expect(k.ValidateClusterForCompatibilityCallCount()).To(Equal(1))
@@ -214,14 +189,12 @@ var _ = DescribeTable("Create", func(t ngEntry) {
 			UpdateAuthConfigMap: true,
 		},
 		mockCalls: func(k *fakes.FakeKubeProvider, init *fakes.FakeNodeGroupInitialiser, f *utilFakes.FakeNodegroupFilter) {
-			k.SupportsManagedNodesReturns(true, nil)
 			k.UpdateAuthConfigMapReturns(errors.New("err"))
 		},
 		expectedCalls: func(k *fakes.FakeKubeProvider, init *fakes.FakeNodeGroupInitialiser, f *utilFakes.FakeNodegroupFilter) {
 			Expect(k.NewRawClientCallCount()).To(Equal(1))
 			Expect(k.ServerVersionCallCount()).To(Equal(1))
 			Expect(k.LoadClusterIntoSpecFromStackCallCount()).To(Equal(1))
-			Expect(k.SupportsManagedNodesCallCount()).To(Equal(1))
 			Expect(init.NewAWSSelectorSessionCallCount()).To(Equal(1))
 			Expect(init.ExpandInstanceSelectorOptionsCallCount()).To(Equal(1))
 			Expect(k.ValidateClusterForCompatibilityCallCount()).To(Equal(1))
@@ -235,14 +208,12 @@ var _ = DescribeTable("Create", func(t ngEntry) {
 
 	Entry("when unable to validate existing ng for compatibility, logs but does not error", ngEntry{
 		mockCalls: func(k *fakes.FakeKubeProvider, init *fakes.FakeNodeGroupInitialiser, f *utilFakes.FakeNodegroupFilter) {
-			k.SupportsManagedNodesReturns(true, nil)
 			init.ValidateExistingNodeGroupsForCompatibilityReturns(errors.New("err"))
 		},
 		expectedCalls: func(k *fakes.FakeKubeProvider, init *fakes.FakeNodeGroupInitialiser, f *utilFakes.FakeNodegroupFilter) {
 			Expect(k.NewRawClientCallCount()).To(Equal(1))
 			Expect(k.ServerVersionCallCount()).To(Equal(1))
 			Expect(k.LoadClusterIntoSpecFromStackCallCount()).To(Equal(1))
-			Expect(k.SupportsManagedNodesCallCount()).To(Equal(1))
 			Expect(init.NewAWSSelectorSessionCallCount()).To(Equal(1))
 			Expect(init.ExpandInstanceSelectorOptionsCallCount()).To(Equal(1))
 			Expect(k.ValidateClusterForCompatibilityCallCount()).To(Equal(1))
@@ -256,13 +227,11 @@ var _ = DescribeTable("Create", func(t ngEntry) {
 
 	Entry("[happy path] creates nodegroup with no options", ngEntry{
 		mockCalls: func(k *fakes.FakeKubeProvider, init *fakes.FakeNodeGroupInitialiser, f *utilFakes.FakeNodegroupFilter) {
-			k.SupportsManagedNodesReturns(true, nil)
 		},
 		expectedCalls: func(k *fakes.FakeKubeProvider, init *fakes.FakeNodeGroupInitialiser, f *utilFakes.FakeNodegroupFilter) {
 			Expect(k.NewRawClientCallCount()).To(Equal(1))
 			Expect(k.ServerVersionCallCount()).To(Equal(1))
 			Expect(k.LoadClusterIntoSpecFromStackCallCount()).To(Equal(1))
-			Expect(k.SupportsManagedNodesCallCount()).To(Equal(1))
 			Expect(init.NewAWSSelectorSessionCallCount()).To(Equal(1))
 			Expect(init.ExpandInstanceSelectorOptionsCallCount()).To(Equal(1))
 			Expect(k.ValidateClusterForCompatibilityCallCount()).To(Equal(1))
@@ -284,13 +253,11 @@ var _ = DescribeTable("Create", func(t ngEntry) {
 			ConfigFileProvided:        true,
 		},
 		mockCalls: func(k *fakes.FakeKubeProvider, init *fakes.FakeNodeGroupInitialiser, f *utilFakes.FakeNodegroupFilter) {
-			k.SupportsManagedNodesReturns(true, nil)
 		},
 		expectedCalls: func(k *fakes.FakeKubeProvider, init *fakes.FakeNodeGroupInitialiser, f *utilFakes.FakeNodegroupFilter) {
 			Expect(k.NewRawClientCallCount()).To(Equal(1))
 			Expect(k.ServerVersionCallCount()).To(Equal(1))
 			Expect(k.LoadClusterIntoSpecFromStackCallCount()).To(Equal(1))
-			Expect(k.SupportsManagedNodesCallCount()).To(Equal(1))
 			Expect(init.NewAWSSelectorSessionCallCount()).To(Equal(1))
 			Expect(init.ExpandInstanceSelectorOptionsCallCount()).To(Equal(1))
 			Expect(k.ValidateClusterForCompatibilityCallCount()).To(Equal(1))
