@@ -685,6 +685,10 @@ func ValidateNodeGroup(i int, ng *NodeGroup) error {
 		}
 	}
 
+	if instanceutils.IsARMGPUInstanceType(SelectInstanceType(ng)) {
+		return errors.Errorf("ARM GPU instance types are not supported for unmanaged nodegroups with AMIFamily %s", ng.AMIFamily)
+	}
+
 	if err := validateInstancesDistribution(ng); err != nil {
 		return err
 	}
