@@ -1,12 +1,17 @@
 package builder_test
 
 import (
+	"context"
 	"encoding/json"
 	"errors"
 	"fmt"
 
-	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/service/ec2"
+	"github.com/stretchr/testify/mock"
+
+	"github.com/aws/aws-sdk-go-v2/aws"
+	"github.com/aws/aws-sdk-go-v2/service/ec2"
+	ec2types "github.com/aws/aws-sdk-go-v2/service/ec2/types"
+
 	. "github.com/onsi/ginkgo"
 	. "github.com/onsi/gomega"
 	gfnt "github.com/weaveworks/goformation/v4/cloudformation/types"
@@ -16,7 +21,7 @@ import (
 	"github.com/weaveworks/eksctl/pkg/cfn/builder/fakes"
 	"github.com/weaveworks/eksctl/pkg/cfn/outputs"
 	cft "github.com/weaveworks/eksctl/pkg/cfn/template"
-	"github.com/weaveworks/eksctl/pkg/eks/mocks"
+	"github.com/weaveworks/eksctl/pkg/eks/mocksv2"
 	bootstrapfakes "github.com/weaveworks/eksctl/pkg/nodebootstrap/fakes"
 	vpcfakes "github.com/weaveworks/eksctl/pkg/vpc/fakes"
 )
@@ -29,8 +34,8 @@ var _ = Describe("Unmanaged NodeGroup Template Builder", func() {
 		forceAddCNIPolicy bool
 		fakeVPCImporter   *vpcfakes.FakeImporter
 		fakeBootstrapper  *bootstrapfakes.FakeBootstrapper
-		mockEC2           = &mocks.EC2API{}
-		mockIAM           = &mocks.IAMAPI{}
+		mockEC2           = &mocksv2.EC2{}
+		mockIAM           = &mocksv2.IAM{}
 	)
 
 	BeforeEach(func() {
@@ -51,7 +56,7 @@ var _ = Describe("Unmanaged NodeGroup Template Builder", func() {
 		)
 
 		JustBeforeEach(func() {
-			addErr = ngrs.AddAllResources()
+			addErr = ngrs.AddAllResources(context.Background())
 			ngTemplate = &fakes.FakeTemplate{}
 			templateBody, err := ngrs.RenderJSON()
 			Expect(err).ShouldNot(HaveOccurred())
@@ -600,17 +605,18 @@ var _ = Describe("Unmanaged NodeGroup Template Builder", func() {
 				BeforeEach(func() {
 					ng.EFAEnabled = aws.Bool(true)
 					mockEC2.On("DescribeInstanceTypes",
+						mock.Anything,
 						&ec2.DescribeInstanceTypesInput{
-							InstanceTypes: aws.StringSlice([]string{"m5.large"}),
+							InstanceTypes: []ec2types.InstanceType{ec2types.InstanceTypeM5Large},
 						},
 					).Return(
 						&ec2.DescribeInstanceTypesOutput{
-							InstanceTypes: []*ec2.InstanceTypeInfo{
+							InstanceTypes: []ec2types.InstanceTypeInfo{
 								{
-									InstanceType: aws.String("m5.large"),
-									NetworkInfo: &ec2.NetworkInfo{
+									InstanceType: ec2types.InstanceTypeM5Large,
+									NetworkInfo: &ec2types.NetworkInfo{
 										EfaSupported:        aws.Bool(true),
-										MaximumNetworkCards: aws.Int64(4),
+										MaximumNetworkCards: aws.Int32(4),
 									},
 								},
 							},
@@ -1257,17 +1263,17 @@ var _ = Describe("Unmanaged NodeGroup Template Builder", func() {
 		})
 
 		It("returns public subnets", func() {
-			subnets, err := builder.AssignSubnets(ngBase, fakeVPCImporter, cfg, nil)
+			subnets, err := builder.AssignSubnets(context.Background(), ngBase, fakeVPCImporter, cfg, nil)
 			Expect(err).NotTo(HaveOccurred())
 			Expect(subnets).To(Equal(gfnt.NewString("subnet-1")))
 		})
 
 		It("returns subnets if they exist and were defined by ID only", func() {
-			mockEC2 = &mocks.EC2API{}
-			mockEC2.On("DescribeSubnets", &ec2.DescribeSubnetsInput{
-				SubnetIds: aws.StringSlice([]string{"fake-id"}),
+			mockEC2 = &mocksv2.EC2{}
+			mockEC2.On("DescribeSubnets", mock.Anything, &ec2.DescribeSubnetsInput{
+				SubnetIds: []string{"fake-id"},
 			}).Return(&ec2.DescribeSubnetsOutput{
-				Subnets: []*ec2.Subnet{
+				Subnets: []ec2types.Subnet{
 					{
 						SubnetId: aws.String("fake-id"),
 						VpcId:    aws.String(cfg.VPC.ID),
@@ -1276,17 +1282,17 @@ var _ = Describe("Unmanaged NodeGroup Template Builder", func() {
 			}, nil)
 			ngBase := ngBase.DeepCopy()
 			ngBase.Subnets = []string{"fake-id"}
-			subnets, err := builder.AssignSubnets(ngBase, fakeVPCImporter, cfg, mockEC2)
+			subnets, err := builder.AssignSubnets(context.Background(), ngBase, fakeVPCImporter, cfg, mockEC2)
 			Expect(err).NotTo(HaveOccurred())
 			Expect(subnets).To(Equal(gfnt.NewStringSlice("fake-id")))
 		})
 
 		It("returns an error if the given subnet is not part of the cluster's VPC", func() {
-			mockEC2 = &mocks.EC2API{}
-			mockEC2.On("DescribeSubnets", &ec2.DescribeSubnetsInput{
-				SubnetIds: aws.StringSlice([]string{"fake-id"}),
+			mockEC2 = &mocksv2.EC2{}
+			mockEC2.On("DescribeSubnets", mock.Anything, &ec2.DescribeSubnetsInput{
+				SubnetIds: []string{"fake-id"},
 			}).Return(&ec2.DescribeSubnetsOutput{
-				Subnets: []*ec2.Subnet{
+				Subnets: []ec2types.Subnet{
 					{
 						SubnetId: aws.String("fake-id"),
 						VpcId:    aws.String("invalid-vpc-id"),
@@ -1295,18 +1301,18 @@ var _ = Describe("Unmanaged NodeGroup Template Builder", func() {
 			}, nil)
 			ngBase := ngBase.DeepCopy()
 			ngBase.Subnets = []string{"fake-id"}
-			_, err := builder.AssignSubnets(ngBase, fakeVPCImporter, cfg, mockEC2)
+			_, err := builder.AssignSubnets(context.Background(), ngBase, fakeVPCImporter, cfg, mockEC2)
 			Expect(err).To(MatchError(ContainSubstring("subnet with id \"fake-id\" is not in the attached vpc with id \"\"")))
 		})
 
 		It("returns an error if ec2 api returns an error", func() {
-			mockEC2 = &mocks.EC2API{}
-			mockEC2.On("DescribeSubnets", &ec2.DescribeSubnetsInput{
-				SubnetIds: aws.StringSlice([]string{"fake-id"}),
+			mockEC2 = &mocksv2.EC2{}
+			mockEC2.On("DescribeSubnets", mock.Anything, &ec2.DescribeSubnetsInput{
+				SubnetIds: []string{"fake-id"},
 			}).Return(nil, errors.New("nope"))
 			ngBase := ngBase.DeepCopy()
 			ngBase.Subnets = []string{"fake-id"}
-			_, err := builder.AssignSubnets(ngBase, fakeVPCImporter, cfg, mockEC2)
+			_, err := builder.AssignSubnets(context.Background(), ngBase, fakeVPCImporter, cfg, mockEC2)
 			Expect(err).To(MatchError(ContainSubstring("nope")))
 		})
 
@@ -1317,7 +1323,7 @@ var _ = Describe("Unmanaged NodeGroup Template Builder", func() {
 			})
 
 			It("returns private subnets", func() {
-				subnets, err := builder.AssignSubnets(ngBase, fakeVPCImporter, cfg, nil)
+				subnets, err := builder.AssignSubnets(context.Background(), ngBase, fakeVPCImporter, cfg, nil)
 				Expect(err).NotTo(HaveOccurred())
 				Expect(subnets).To(Equal(gfnt.NewString("subnet-2")))
 			})
@@ -1330,7 +1336,7 @@ var _ = Describe("Unmanaged NodeGroup Template Builder", func() {
 			})
 
 			It("maps subnets to azs", func() {
-				subnets, err := builder.AssignSubnets(ngBase, fakeVPCImporter, cfg, nil)
+				subnets, err := builder.AssignSubnets(context.Background(), ngBase, fakeVPCImporter, cfg, nil)
 				Expect(err).NotTo(HaveOccurred())
 				Expect(subnets).To(Equal(gfnt.NewStringSlice(publicSubnet1, publicSubnet2)))
 			})
@@ -1342,7 +1348,7 @@ var _ = Describe("Unmanaged NodeGroup Template Builder", func() {
 				})
 
 				It("maps private subnets to azs", func() {
-					subnets, err := builder.AssignSubnets(ngBase, fakeVPCImporter, cfg, nil)
+					subnets, err := builder.AssignSubnets(context.Background(), ngBase, fakeVPCImporter, cfg, nil)
 					Expect(err).NotTo(HaveOccurred())
 					Expect(subnets).To(Equal(gfnt.NewStringSlice(privateSubnet1, privateSubnet2)))
 				})
@@ -1354,11 +1360,11 @@ var _ = Describe("Unmanaged NodeGroup Template Builder", func() {
 				})
 
 				It("returns the error", func() {
-					mockEC2 = &mocks.EC2API{}
-					mockEC2.On("DescribeSubnets", &ec2.DescribeSubnetsInput{
-						SubnetIds: aws.StringSlice([]string{"not-a-thing"}),
+					mockEC2 = &mocksv2.EC2{}
+					mockEC2.On("DescribeSubnets", mock.Anything, &ec2.DescribeSubnetsInput{
+						SubnetIds: []string{"not-a-thing"},
 					}).Return(nil, errors.New("nope"))
-					_, err := builder.AssignSubnets(ngBase, fakeVPCImporter, cfg, mockEC2)
+					_, err := builder.AssignSubnets(context.Background(), ngBase, fakeVPCImporter, cfg, mockEC2)
 					Expect(err).To(MatchError(ContainSubstring("couldn't find public subnets")))
 				})
 			})
@@ -1371,7 +1377,7 @@ var _ = Describe("Unmanaged NodeGroup Template Builder", func() {
 			})
 
 			It("choses only the first subnet", func() {
-				subnets, err := builder.AssignSubnets(ngBase, fakeVPCImporter, cfg, nil)
+				subnets, err := builder.AssignSubnets(context.Background(), ngBase, fakeVPCImporter, cfg, nil)
 				Expect(err).NotTo(HaveOccurred())
 				Expect(subnets).To(Equal(gfnt.NewStringSlice(publicSubnet1)))
 			})
