@@ -1,6 +1,7 @@
 package builder
 
 import (
+	"context"
 	"math"
 	"strings"
 
@@ -49,8 +50,8 @@ const (
 
 //VPCResourceSet interface for creating cloudformation resource sets for generating VPC resources
 type VPCResourceSet interface {
-	//CreateTemplate generates all of the resources & outputs required for the VPC. Returns the
-	CreateTemplate() (vpcID *gfnt.Value, subnetDetails *SubnetDetails, err error)
+	// CreateTemplate generates all of the resources & outputs required for the VPC. Returns the
+	CreateTemplate(ctx context.Context) (vpcID *gfnt.Value, subnetDetails *SubnetDetails, err error)
 }
 
 func formatAZ(az string) string {
