@@ -4,13 +4,18 @@ import (
 	"context"
 	"fmt"
 	"regexp"
+	"strings"
 	"time"
 
+	"github.com/aws/aws-sdk-go-v2/service/autoscaling"
+	asTypes "github.com/aws/aws-sdk-go-v2/service/autoscaling/types"
+	"github.com/aws/aws-sdk-go-v2/service/cloudformation"
+	"github.com/aws/aws-sdk-go-v2/service/cloudformation/types"
 	"github.com/aws/aws-sdk-go-v2/service/cloudtrail"
-	"github.com/aws/aws-sdk-go-v2/service/cloudtrail/types"
+	"github.com/aws/smithy-go"
+
+	cttypes "github.com/aws/aws-sdk-go-v2/service/cloudtrail/types"
 	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/service/cloudformation"
-	"github.com/aws/aws-sdk-go/service/cloudformation/cloudformationiface"
 	"github.com/aws/aws-sdk-go/service/eks/eksiface"
 	"github.com/kris-nova/logger"
 	"github.com/pkg/errors"
@@ -23,25 +28,26 @@ import (
 )
 
 const (
-	resourcesRootPath = "Resources"
-	outputsRootPath   = "Outputs"
-	mappingsRootPath  = "Mappings"
-	ourStackRegexFmt  = "^(eksctl|EKS)-%s-((cluster|nodegroup-.+|addon-.+|fargate|karpenter)|(VPC|ServiceRole|ControlPlane|DefaultNodeGroup))$"
-	clusterStackRegex = "eksctl-.*-cluster"
+	resourcesRootPath            = "Resources"
+	resourceTypeAutoScalingGroup = "auto-scaling-group"
+	outputsRootPath              = "Outputs"
+	mappingsRootPath             = "Mappings"
+	ourStackRegexFmt             = "^(eksctl|EKS)-%s-((cluster|nodegroup-.+|addon-.+|fargate|karpenter)|(VPC|ServiceRole|ControlPlane|DefaultNodeGroup))$"
+	clusterStackRegex            = "eksctl-.*-cluster"
 )
 
 var (
-	stackCapabilitiesIAM      = aws.StringSlice([]string{cloudformation.CapabilityCapabilityIam})
-	stackCapabilitiesNamedIAM = aws.StringSlice([]string{cloudformation.CapabilityCapabilityNamedIam})
+	stackCapabilitiesIAM      = []types.Capability{types.CapabilityCapabilityIam}
+	stackCapabilitiesNamedIAM = []types.Capability{types.CapabilityCapabilityNamedIam}
 )
 
 // Stack represents the CloudFormation stack
-type Stack = cloudformation.Stack
+type Stack = types.Stack
 
 // StackInfo hold the stack along with template and resources
 type StackInfo struct {
 	Stack     *Stack
-	Resources []*cloudformation.StackResource
+	Resources []types.StackResource
 }
 
 // TemplateData is a union (sum type) to describe template data.
@@ -64,7 +70,7 @@ type ChangeSet = cloudformation.DescribeChangeSetOutput
 
 // StackCollection stores the CloudFormation stack information
 type StackCollection struct {
-	cloudformationAPI cloudformationiface.CloudFormationAPI
+	cloudformationAPI awsapi.CloudFormation
 	ec2API            awsapi.EC2
 	eksAPI            eksiface.EKSAPI
 	iamAPI            awsapi.IAM
@@ -76,16 +82,16 @@ type StackCollection struct {
 	roleARN         string
 	region          string
 	waitTimeout     time.Duration
-	sharedTags      []*cloudformation.Tag
+	sharedTags      []types.Tag
 }
 
-func newTag(key, value string) *cloudformation.Tag {
-	return &cloudformation.Tag{Key: &key, Value: &value}
+func newTag(key, value string) types.Tag {
+	return types.Tag{Key: &key, Value: &value}
 }
 
 // NewStackCollection creates a stack manager for a single cluster
 func NewStackCollection(provider api.ClusterProvider, spec *api.ClusterConfig) StackManager {
-	tags := []*cloudformation.Tag{
+	tags := []types.Tag{
 		newTag(api.ClusterNameTag, spec.Metadata.Name),
 		newTag(api.OldClusterNameTag, spec.Metadata.Name),
 		newTag(api.EksctlVersionTag, version.GetVersion()),
@@ -110,7 +116,7 @@ func NewStackCollection(provider api.ClusterProvider, spec *api.ClusterConfig) S
 }
 
 // DoCreateStackRequest requests the creation of a CloudFormation stack
-func (c *StackCollection) DoCreateStackRequest(i *Stack, templateData TemplateData, tags, parameters map[string]string, withIAM bool, withNamedIAM bool) error {
+func (c *StackCollection) DoCreateStackRequest(ctx context.Context, i *Stack, templateData TemplateData, tags, parameters map[string]string, withIAM bool, withNamedIAM bool) error {
 	input := &cloudformation.CreateStackInput{
 		StackName:       i.StackName,
 		DisableRollback: aws.Bool(c.disableRollback),
@@ -122,35 +128,34 @@ func (c *StackCollection) DoCreateStackRequest(i *Stack, templateData TemplateDa
 
 	switch data := templateData.(type) {
 	case TemplateBody:
-		input.SetTemplateBody(string(data))
+		input.TemplateBody = aws.String(string(data))
 	case TemplateURL:
-		input.SetTemplateURL(string(data))
+		input.TemplateURL = aws.String(string(data))
 	default:
 		return fmt.Errorf("unknown template data type: %T", templateData)
 	}
 
 	if withIAM {
-		input.SetCapabilities(stackCapabilitiesIAM)
+		input.Capabilities = stackCapabilitiesIAM
 	}
 
 	if withNamedIAM {
-		input.SetCapabilities(stackCapabilitiesNamedIAM)
+		input.Capabilities = stackCapabilitiesNamedIAM
 	}
 
 	if cfnRole := c.roleARN; cfnRole != "" {
-		input = input.SetRoleARN(cfnRole)
+		input.RoleARN = aws.String(cfnRole)
 	}
 
 	for k, v := range parameters {
-		p := &cloudformation.Parameter{
+		input.Parameters = append(input.Parameters, types.Parameter{
 			ParameterKey:   aws.String(k),
 			ParameterValue: aws.String(v),
-		}
-		input.Parameters = append(input.Parameters, p)
+		})
 	}
 
 	logger.Debug("CreateStackInput = %#v", input)
-	s, err := c.cloudformationAPI.CreateStack(input)
+	s, err := c.cloudformationAPI.CreateStack(ctx, input)
 	if err != nil {
 		return errors.Wrapf(err, "creating CloudFormation stack %q", *i.StackName)
 	}
@@ -162,35 +167,35 @@ func (c *StackCollection) DoCreateStackRequest(i *Stack, templateData TemplateDa
 // any errors will be written to errs channel, when nil is written,
 // assume completion, do not expect more then one error value on the
 // channel, it's closed immediately after it is written to
-func (c *StackCollection) CreateStack(stackName string, resourceSet builder.ResourceSetReader, tags, parameters map[string]string, errs chan error) error {
-	stack, err := c.createStackRequest(stackName, resourceSet, tags, parameters)
+func (c *StackCollection) CreateStack(ctx context.Context, stackName string, resourceSet builder.ResourceSetReader, tags, parameters map[string]string, errs chan error) error {
+	stack, err := c.createStackRequest(ctx, stackName, resourceSet, tags, parameters)
 	if err != nil {
 		return err
 	}
 
-	go c.waitUntilStackIsCreated(stack, resourceSet, errs)
+	go c.waitUntilStackIsCreated(ctx, stack, resourceSet, errs)
 	return nil
 }
 
 // createClusterStack creates the cluster stack
-func (c *StackCollection) createClusterStack(stackName string, resourceSet builder.ResourceSetReader, errCh chan error) error {
+func (c *StackCollection) createClusterStack(ctx context.Context, stackName string, resourceSet builder.ResourceSetReader, errCh chan error) error {
 	// Unlike with `createNodeGroupTask`, all tags are already set for the cluster stack
-	stack, err := c.createStackRequest(stackName, resourceSet, nil, nil)
+	stack, err := c.createStackRequest(ctx, stackName, resourceSet, nil, nil)
 	if err != nil {
 		return err
 	}
 	go func() {
 		defer close(errCh)
 		troubleshoot := func() {
-			stack, err := c.DescribeStack(stack)
+			stack, err := c.DescribeStack(ctx, stack)
 			if err != nil {
 				logger.Info("error describing stack to troubleshoot the cause of the failure; "+
 					"check the CloudFormation console for further details", err)
 				return
 			}
 
-			logger.Critical("unexpected status %q while waiting for CloudFormation stack %q", *stack.StackStatus, *stack.StackName)
-			c.troubleshootStackFailureCause(stack, cloudformation.StackStatusCreateComplete)
+			logger.Critical("unexpected status %q while waiting for CloudFormation stack %q", stack.StackStatus, *stack.StackName)
+			c.troubleshootStackFailureCause(ctx, stack, string(types.StackStatusCreateComplete))
 		}
 
 		ctx, cancelFunc := context.WithTimeout(context.Background(), c.waitTimeout)
@@ -221,14 +226,14 @@ func (c *StackCollection) createClusterStack(stackName string, resourceSet build
 	return nil
 }
 
-func (c *StackCollection) createStackRequest(stackName string, resourceSet builder.ResourceSetReader, tags, parameters map[string]string) (*Stack, error) {
+func (c *StackCollection) createStackRequest(ctx context.Context, stackName string, resourceSet builder.ResourceSetReader, tags, parameters map[string]string) (*Stack, error) {
 	stack := &Stack{StackName: &stackName}
 	templateBody, err := resourceSet.RenderJSON()
 	if err != nil {
 		return nil, errors.Wrapf(err, "rendering template for %q stack", *stack.StackName)
 	}
 
-	if err := c.DoCreateStackRequest(stack, TemplateBody(templateBody), tags, parameters, resourceSet.WithIAM(), resourceSet.WithNamedIAM()); err != nil {
+	if err := c.DoCreateStackRequest(ctx, stack, TemplateBody(templateBody), tags, parameters, resourceSet.WithIAM(), resourceSet.WithNamedIAM()); err != nil {
 		return nil, err
 	}
 
@@ -236,13 +241,99 @@ func (c *StackCollection) createStackRequest(stackName string, resourceSet build
 	return stack, nil
 }
 
+func (c *StackCollection) PropagateManagedNodeGroupTagsToASG(ngName string, ngTags map[string]string, asgNames []string, errCh chan error) error {
+	go func() {
+		defer close(errCh)
+		// build the input tags for all ASGs attached to the managed nodegroup
+		asgTags := []asTypes.Tag{}
+
+		for _, asgName := range asgNames {
+			// skip directly if not tags are required to be created
+			if len(ngTags) == 0 {
+				continue
+			}
+
+			// check if the number of tags on the ASG would go over the defined limit
+			if err := c.checkASGTagsNumber(ngName, asgName, ngTags); err != nil {
+				errCh <- err
+				return
+			}
+			// build the list of tags to attach to the ASG
+			for ngTagKey, ngTagValue := range ngTags {
+				asgTag := asTypes.Tag{
+					ResourceId:        aws.String(asgName),
+					ResourceType:      aws.String(resourceTypeAutoScalingGroup),
+					Key:               aws.String(ngTagKey),
+					Value:             aws.String(ngTagValue),
+					PropagateAtLaunch: aws.Bool(false),
+				}
+				asgTags = append(asgTags, asgTag)
+			}
+		}
+
+		// consider the maximum number of tags we can create at once...
+		var chunkedASGTags [][]asTypes.Tag
+		chunkSize := builder.MaximumCreatedTagNumberPerCall
+		for start := 0; start < len(asgTags); start += chunkSize {
+			end := start + chunkSize
+			if end > len(asgTags) {
+				end = len(asgTags)
+			}
+			chunkedASGTags = append(chunkedASGTags, asgTags[start:end])
+		}
+		// ...then create all of them in a loop
+		for _, asgTags := range chunkedASGTags {
+			input := &autoscaling.CreateOrUpdateTagsInput{Tags: asgTags}
+			if _, err := c.asgAPI.CreateOrUpdateTags(context.Background(), input); err != nil {
+				errCh <- errors.Wrapf(err, "creating or updating asg tags for managed nodegroup %q", ngName)
+				return
+			}
+		}
+		errCh <- nil
+	}()
+	return nil
+}
+
+// checkASGTagsNumber limit considering the new propagated tags
+func (c *StackCollection) checkASGTagsNumber(ngName, asgName string, propagatedTags map[string]string) error {
+	tagsFilter := &autoscaling.DescribeTagsInput{
+		Filters: []asTypes.Filter{
+			{
+				Name:   aws.String(resourceTypeAutoScalingGroup),
+				Values: []string{asgName},
+			},
+		},
+	}
+	output, err := c.asgAPI.DescribeTags(context.Background(), tagsFilter)
+	if err != nil {
+		return errors.Wrapf(err, "describing asg %q tags for managed nodegroup %q", asgName, ngName)
+	}
+	asgTags := output.Tags
+	// intersection of key tags to consider the number of tags going
+	// to be attached to the ASG
+	uniqueTagKeyCount := len(asgTags) + len(propagatedTags)
+	for ngTagKey := range propagatedTags {
+		for _, asgTag := range asgTags {
+			// decrease the unique tag key count if there is a match
+			if aws.StringValue(asgTag.Key) == ngTagKey {
+				uniqueTagKeyCount--
+				break
+			}
+		}
+	}
+	if uniqueTagKeyCount > builder.MaximumTagNumber {
+		return fmt.Errorf("number of tags is exceeding the maximum amount for asg %d, was: %d", builder.MaximumTagNumber, uniqueTagKeyCount)
+	}
+	return nil
+}
+
 // UpdateStack will update a CloudFormation stack by creating and executing a ChangeSet
-func (c *StackCollection) UpdateStack(options UpdateStackOptions) error {
+func (c *StackCollection) UpdateStack(ctx context.Context, options UpdateStackOptions) error {
 	logger.Info(options.Description)
 	if options.Stack == nil {
 		i := &Stack{StackName: &options.StackName}
 		// Read existing tags
-		s, err := c.DescribeStack(i)
+		s, err := c.DescribeStack(ctx, i)
 		if err != nil {
 			return err
 		}
@@ -250,7 +341,7 @@ func (c *StackCollection) UpdateStack(options UpdateStackOptions) error {
 	} else {
 		options.StackName = *options.Stack.StackName
 	}
-	if err := c.doCreateChangeSetRequest(
+	if err := c.doCreateChangeSetRequest(ctx,
 		options.StackName,
 		options.ChangeSetName,
 		options.Description,
@@ -261,48 +352,54 @@ func (c *StackCollection) UpdateStack(options UpdateStackOptions) error {
 	); err != nil {
 		return err
 	}
-	if err := c.doWaitUntilChangeSetIsCreated(options.Stack, options.ChangeSetName); err != nil {
+	if err := c.doWaitUntilChangeSetIsCreated(ctx, options.Stack, options.ChangeSetName); err != nil {
 		if _, ok := err.(*noChangeError); ok {
 			return nil
 		}
 		return err
 	}
-	changeSet, err := c.DescribeStackChangeSet(options.Stack, options.ChangeSetName)
+	changeSet, err := c.DescribeStackChangeSet(ctx, options.Stack, options.ChangeSetName)
 	if err != nil {
 		return err
 	}
 	logger.Debug("changes = %#v", changeSet.Changes)
-	if err := c.doExecuteChangeSet(options.StackName, options.ChangeSetName); err != nil {
+	if err := c.doExecuteChangeSet(ctx, options.StackName, options.ChangeSetName); err != nil {
 		logger.Warning("error executing Cloudformation changeSet %s in stack %s. Check the Cloudformation console for further details", options.ChangeSetName, options.StackName)
 		return err
 	}
 	if options.Wait {
-		return c.doWaitUntilStackIsUpdated(options.Stack)
+		return c.doWaitUntilStackIsUpdated(ctx, options.Stack)
 	}
 	return nil
 }
 
 // DescribeStack describes a cloudformation stack.
-func (c *StackCollection) DescribeStack(i *Stack) (*Stack, error) {
+func (c *StackCollection) DescribeStack(ctx context.Context, i *Stack) (*Stack, error) {
 	input := &cloudformation.DescribeStacksInput{
 		StackName: i.StackName,
 	}
 	if api.IsSetAndNonEmptyString(i.StackId) {
 		input.StackName = i.StackId
 	}
-	resp, err := c.cloudformationAPI.DescribeStacks(input)
+	resp, err := c.cloudformationAPI.DescribeStacks(ctx, input)
 	if err != nil {
 		return nil, errors.Wrapf(err, "describing CloudFormation stack %q", *i.StackName)
 	}
 	if len(resp.Stacks) == 0 {
 		return nil, fmt.Errorf("no CloudFormation stack found for %s", *i.StackName)
 	}
-	return resp.Stacks[0], nil
+	return &resp.Stacks[0], nil
+}
+
+func IsStackDoesNotExistError(err error) bool {
+	awsError, ok := errors.Unwrap(errors.Unwrap(err)).(*smithy.OperationError)
+	return ok && strings.Contains(awsError.Error(), "ValidationError")
+
 }
 
 // GetManagedNodeGroupTemplate returns the template for a ManagedNodeGroup resource
-func (c *StackCollection) GetManagedNodeGroupTemplate(options GetNodegroupOption) (string, error) {
-	nodeGroupType, err := c.GetNodeGroupStackType(options)
+func (c *StackCollection) GetManagedNodeGroupTemplate(ctx context.Context, options GetNodegroupOption) (string, error) {
+	nodeGroupType, err := c.GetNodeGroupStackType(ctx, options)
 	if err != nil {
 		return "", err
 	}
@@ -312,7 +409,7 @@ func (c *StackCollection) GetManagedNodeGroupTemplate(options GetNodegroupOption
 	}
 
 	stackName := c.makeNodeGroupStackName(options.NodeGroupName)
-	templateBody, err := c.GetStackTemplate(stackName)
+	templateBody, err := c.GetStackTemplate(ctx, stackName)
 	if err != nil {
 		return "", err
 	}
@@ -321,9 +418,9 @@ func (c *StackCollection) GetManagedNodeGroupTemplate(options GetNodegroupOption
 }
 
 // UpdateNodeGroupStack updates the nodegroup stack with the specified template
-func (c *StackCollection) UpdateNodeGroupStack(nodeGroupName, template string, wait bool) error {
+func (c *StackCollection) UpdateNodeGroupStack(ctx context.Context, nodeGroupName, template string, wait bool) error {
 	stackName := c.makeNodeGroupStackName(nodeGroupName)
-	return c.UpdateStack(UpdateStackOptions{
+	return c.UpdateStack(ctx, UpdateStackOptions{
 		StackName:     stackName,
 		ChangeSetName: c.MakeChangeSetName("update-nodegroup"),
 		Description:   "updating nodegroup stack",
@@ -333,7 +430,7 @@ func (c *StackCollection) UpdateNodeGroupStack(nodeGroupName, template string, w
 }
 
 // ListStacksMatching gets all of CloudFormation stacks with names matching nameRegex.
-func (c *StackCollection) ListStacksMatching(nameRegex string, statusFilters ...string) ([]*Stack, error) {
+func (c *StackCollection) ListStacksMatching(ctx context.Context, nameRegex string, statusFilters ...types.StackStatus) ([]*Stack, error) {
 	var (
 		subErr error
 		stack  *Stack
@@ -347,33 +444,35 @@ func (c *StackCollection) ListStacksMatching(nameRegex string, statusFilters ...
 		StackStatusFilter: defaultStackStatusFilter(),
 	}
 	if len(statusFilters) > 0 {
-		input.StackStatusFilter = aws.StringSlice(statusFilters)
+		input.StackStatusFilter = statusFilters
 	}
 	stacks := []*Stack{}
 
-	pager := func(p *cloudformation.ListStacksOutput, _ bool) bool {
-		for _, s := range p.StackSummaries {
+	paginator := cloudformation.NewListStacksPaginator(c.cloudformationAPI, input)
+
+	for paginator.HasMorePages() {
+		out, err := paginator.NextPage(ctx)
+		if err != nil {
+			return nil, err
+		}
+
+		for _, s := range out.StackSummaries {
 			if re.MatchString(*s.StackName) {
-				stack, subErr = c.DescribeStack(&Stack{StackName: s.StackName, StackId: s.StackId})
+				stack, subErr = c.DescribeStack(ctx, &Stack{StackName: s.StackName, StackId: s.StackId})
 				if subErr != nil {
-					return false
+					// this shouldn't return the error, but just stop the pagination and return whatever it gathered so far.
+					return stacks, nil
 				}
 				stacks = append(stacks, stack)
 			}
 		}
-		return true
-	}
-	if err := c.cloudformationAPI.ListStacksPages(input, pager); err != nil {
-		return nil, err
-	}
-	if subErr != nil {
-		return nil, subErr
 	}
+
 	return stacks, nil
 }
 
 // ListClusterStackNames gets all stack names matching regex
-func (c *StackCollection) ListClusterStackNames() ([]string, error) {
+func (c *StackCollection) ListClusterStackNames(ctx context.Context) ([]string, error) {
 	var stacks []string
 	re, err := regexp.Compile(clusterStackRegex)
 	if err != nil {
@@ -383,99 +482,102 @@ func (c *StackCollection) ListClusterStackNames() ([]string, error) {
 		StackStatusFilter: defaultStackStatusFilter(),
 	}
 
-	pager := func(p *cloudformation.ListStacksOutput, _ bool) bool {
-		for _, s := range p.StackSummaries {
+	paginator := cloudformation.NewListStacksPaginator(c.cloudformationAPI, input)
+
+	for paginator.HasMorePages() {
+		out, err := paginator.NextPage(ctx)
+		if err != nil {
+			return nil, err
+		}
+
+		for _, s := range out.StackSummaries {
 			if re.MatchString(*s.StackName) {
 				stacks = append(stacks, *s.StackName)
 			}
 		}
-		return true
-	}
-	if err := c.cloudformationAPI.ListStacksPages(input, pager); err != nil {
-		return nil, err
 	}
 
 	return stacks, nil
 }
 
 // ListStacks gets all of CloudFormation stacks
-func (c *StackCollection) ListStacks(statusFilters ...string) ([]*Stack, error) {
-	return c.ListStacksMatching(fmtStacksRegexForCluster(c.spec.Metadata.Name), statusFilters...)
+func (c *StackCollection) ListStacks(ctx context.Context, statusFilters ...types.StackStatus) ([]*Stack, error) {
+	return c.ListStacksMatching(ctx, fmtStacksRegexForCluster(c.spec.Metadata.Name), statusFilters...)
 }
 
 // StackStatusIsNotTransitional will return true when stack status is non-transitional
 func (*StackCollection) StackStatusIsNotTransitional(s *Stack) bool {
 	for _, state := range nonTransitionalReadyStackStatuses() {
-		if *s.StackStatus == state {
+		if s.StackStatus == state {
 			return true
 		}
 	}
 	return false
 }
 
-func nonTransitionalReadyStackStatuses() []string {
-	return []string{
-		cloudformation.StackStatusCreateComplete,
-		cloudformation.StackStatusUpdateComplete,
-		cloudformation.StackStatusRollbackComplete,
-		cloudformation.StackStatusUpdateRollbackComplete,
+func nonTransitionalReadyStackStatuses() []types.StackStatus {
+	return []types.StackStatus{
+		types.StackStatusCreateComplete,
+		types.StackStatusUpdateComplete,
+		types.StackStatusRollbackComplete,
+		types.StackStatusUpdateRollbackComplete,
 	}
 }
 
 // StackStatusIsNotReady will return true when stack statate is non-ready
 func (*StackCollection) StackStatusIsNotReady(s *Stack) bool {
 	for _, state := range nonReadyStackStatuses() {
-		if *s.StackStatus == state {
+		if s.StackStatus == state {
 			return true
 		}
 	}
 	return false
 }
 
-func nonReadyStackStatuses() []string {
-	return []string{
-		cloudformation.StackStatusCreateInProgress,
-		cloudformation.StackStatusCreateFailed,
-		cloudformation.StackStatusRollbackInProgress,
-		cloudformation.StackStatusRollbackFailed,
-		cloudformation.StackStatusDeleteInProgress,
-		cloudformation.StackStatusDeleteFailed,
-		cloudformation.StackStatusUpdateInProgress,
-		cloudformation.StackStatusUpdateCompleteCleanupInProgress,
-		cloudformation.StackStatusUpdateRollbackInProgress,
-		cloudformation.StackStatusUpdateRollbackFailed,
-		cloudformation.StackStatusUpdateRollbackCompleteCleanupInProgress,
-		cloudformation.StackStatusReviewInProgress,
+func nonReadyStackStatuses() []types.StackStatus {
+	return []types.StackStatus{
+		types.StackStatusCreateInProgress,
+		types.StackStatusCreateFailed,
+		types.StackStatusRollbackInProgress,
+		types.StackStatusRollbackFailed,
+		types.StackStatusDeleteInProgress,
+		types.StackStatusDeleteFailed,
+		types.StackStatusUpdateInProgress,
+		types.StackStatusUpdateCompleteCleanupInProgress,
+		types.StackStatusUpdateRollbackInProgress,
+		types.StackStatusUpdateRollbackFailed,
+		types.StackStatusUpdateRollbackCompleteCleanupInProgress,
+		types.StackStatusReviewInProgress,
 	}
 }
 
-func allNonDeletedStackStatuses() []string {
-	return []string{
-		cloudformation.StackStatusCreateInProgress,
-		cloudformation.StackStatusCreateFailed,
-		cloudformation.StackStatusCreateComplete,
-		cloudformation.StackStatusRollbackInProgress,
-		cloudformation.StackStatusRollbackFailed,
-		cloudformation.StackStatusRollbackComplete,
-		cloudformation.StackStatusDeleteInProgress,
-		cloudformation.StackStatusDeleteFailed,
-		cloudformation.StackStatusUpdateInProgress,
-		cloudformation.StackStatusUpdateCompleteCleanupInProgress,
-		cloudformation.StackStatusUpdateComplete,
-		cloudformation.StackStatusUpdateRollbackInProgress,
-		cloudformation.StackStatusUpdateRollbackFailed,
-		cloudformation.StackStatusUpdateRollbackCompleteCleanupInProgress,
-		cloudformation.StackStatusUpdateRollbackComplete,
-		cloudformation.StackStatusReviewInProgress,
+func allNonDeletedStackStatuses() []types.StackStatus {
+	return []types.StackStatus{
+		types.StackStatusCreateInProgress,
+		types.StackStatusCreateFailed,
+		types.StackStatusCreateComplete,
+		types.StackStatusRollbackInProgress,
+		types.StackStatusRollbackFailed,
+		types.StackStatusRollbackComplete,
+		types.StackStatusDeleteInProgress,
+		types.StackStatusDeleteFailed,
+		types.StackStatusUpdateInProgress,
+		types.StackStatusUpdateCompleteCleanupInProgress,
+		types.StackStatusUpdateComplete,
+		types.StackStatusUpdateRollbackInProgress,
+		types.StackStatusUpdateRollbackFailed,
+		types.StackStatusUpdateRollbackCompleteCleanupInProgress,
+		types.StackStatusUpdateRollbackComplete,
+		types.StackStatusReviewInProgress,
 	}
 }
 
-func defaultStackStatusFilter() []*string {
-	return aws.StringSlice(allNonDeletedStackStatuses())
+func defaultStackStatusFilter() []types.StackStatus {
+	return allNonDeletedStackStatuses()
 }
 
 // DeleteStackBySpec sends a request to delete the stack
-func (c *StackCollection) DeleteStackBySpec(s *Stack) (*Stack, error) {
+func (c *StackCollection) DeleteStackBySpec(ctx context.Context, s *Stack) (*Stack, error) {
 	if !matchesCluster(c.spec.Metadata.Name, s.Tags) {
 		return nil, fmt.Errorf("cannot delete stack %q as it doesn't bear our %q, %q tags", *s.StackName,
 			fmt.Sprintf("%s:%s", api.OldClusterNameTag, c.spec.Metadata.Name),
@@ -487,17 +589,17 @@ func (c *StackCollection) DeleteStackBySpec(s *Stack) (*Stack, error) {
 	}
 
 	if cfnRole := c.roleARN; cfnRole != "" {
-		input = input.SetRoleARN(cfnRole)
+		input.RoleARN = &cfnRole
 	}
 
-	if _, err := c.cloudformationAPI.DeleteStack(input); err != nil {
+	if _, err := c.cloudformationAPI.DeleteStack(ctx, input); err != nil {
 		return nil, errors.Wrapf(err, "not able to delete stack %q", *s.StackName)
 	}
 	logger.Info("will delete stack %q", *s.StackName)
 	return s, nil
 }
 
-func matchesCluster(clusterName string, tags []*cloudformation.Tag) bool {
+func matchesCluster(clusterName string, tags []types.Tag) bool {
 	for _, tag := range tags {
 		switch *tag.Key {
 		case api.ClusterNameTag, api.OldClusterNameTag:
@@ -512,28 +614,28 @@ func matchesCluster(clusterName string, tags []*cloudformation.Tag) bool {
 // DeleteStackBySpecSync sends a request to delete the stack, and waits until status is DELETE_COMPLETE;
 // any errors will be written to errs channel, assume completion when nil is written, do not expect
 // more then one error value on the channel, it's closed immediately after it is written to
-func (c *StackCollection) DeleteStackBySpecSync(s *Stack, errs chan error) error {
-	i, err := c.DeleteStackBySpec(s)
+func (c *StackCollection) DeleteStackBySpecSync(ctx context.Context, s *Stack, errs chan error) error {
+	i, err := c.DeleteStackBySpec(ctx, s)
 	if err != nil {
 		return err
 	}
 
 	logger.Info("waiting for stack %q to get deleted", *i.StackName)
 
-	go c.waitUntilStackIsDeleted(i, errs)
+	go c.waitUntilStackIsDeleted(ctx, i, errs)
 
 	return nil
 }
 
 // DeleteStackSync sends a request to delete the stack, and waits until status is DELETE_COMPLETE;
-func (c *StackCollection) DeleteStackSync(s *Stack) error {
-	i, err := c.DeleteStackBySpec(s)
+func (c *StackCollection) DeleteStackSync(ctx context.Context, s *Stack) error {
+	i, err := c.DeleteStackBySpec(ctx, s)
 	if err != nil {
 		return err
 	}
 
 	logger.Info("waiting for stack %q to get deleted", *i.StackName)
-	return c.doWaitUntilStackIsDeleted(s)
+	return c.doWaitUntilStackIsDeleted(ctx, s)
 }
 
 func fmtStacksRegexForCluster(name string) string {
@@ -541,8 +643,8 @@ func fmtStacksRegexForCluster(name string) string {
 }
 
 // DescribeStacks describes the existing stacks
-func (c *StackCollection) DescribeStacks() ([]*Stack, error) {
-	stacks, err := c.ListStacks()
+func (c *StackCollection) DescribeStacks(ctx context.Context) ([]*Stack, error) {
+	stacks, err := c.ListStacks(ctx)
 	if err != nil {
 		return nil, errors.Wrapf(err, "describing CloudFormation stacks for %q", c.spec.Metadata.Name)
 	}
@@ -552,20 +654,20 @@ func (c *StackCollection) DescribeStacks() ([]*Stack, error) {
 	return stacks, nil
 }
 
-func (c *StackCollection) GetClusterStackIfExists() (*Stack, error) {
-	clusterStackNames, err := c.ListClusterStackNames()
+func (c *StackCollection) GetClusterStackIfExists(ctx context.Context) (*Stack, error) {
+	clusterStackNames, err := c.ListClusterStackNames(ctx)
 	if err != nil {
 		return nil, err
 	}
-	return c.getClusterStackFromList(clusterStackNames, c.spec.Metadata.Name)
+	return c.getClusterStackFromList(ctx, clusterStackNames, c.spec.Metadata.Name)
 }
 
-func (c *StackCollection) HasClusterStackFromList(clusterStackNames []string, clusterName string) (bool, error) {
-	stack, err := c.getClusterStackFromList(clusterStackNames, clusterName)
+func (c *StackCollection) HasClusterStackFromList(ctx context.Context, clusterStackNames []string, clusterName string) (bool, error) {
+	stack, err := c.getClusterStackFromList(ctx, clusterStackNames, clusterName)
 	return stack != nil, err
 }
 
-func (c *StackCollection) getClusterStackFromList(clusterStackNames []string, clusterName string) (*Stack, error) {
+func (c *StackCollection) getClusterStackFromList(ctx context.Context, clusterStackNames []string, clusterName string) (*Stack, error) {
 	clusterStackName := c.MakeClusterStackName()
 	if clusterName != "" {
 		clusterStackName = c.MakeClusterStackNameFromName(clusterName)
@@ -573,7 +675,7 @@ func (c *StackCollection) getClusterStackFromList(clusterStackNames []string, cl
 
 	for _, stack := range clusterStackNames {
 		if stack == clusterStackName {
-			stack, err := c.DescribeStack(&cloudformation.Stack{StackName: &clusterStackName})
+			stack, err := c.DescribeStack(ctx, &types.Stack{StackName: &clusterStackName})
 			if err != nil {
 				return nil, err
 			}
@@ -587,7 +689,7 @@ func (c *StackCollection) getClusterStackFromList(clusterStackNames []string, cl
 }
 
 // DescribeStackEvents describes the events that have occurred on the stack
-func (c *StackCollection) DescribeStackEvents(i *Stack) ([]*cloudformation.StackEvent, error) {
+func (c *StackCollection) DescribeStackEvents(ctx context.Context, i *Stack) ([]types.StackEvent, error) {
 	input := &cloudformation.DescribeStackEventsInput{
 		StackName: i.StackName,
 	}
@@ -595,29 +697,23 @@ func (c *StackCollection) DescribeStackEvents(i *Stack) ([]*cloudformation.Stack
 		input.StackName = i.StackId
 	}
 
-	events := []*cloudformation.StackEvent{}
-
-	pager := func(p *cloudformation.DescribeStackEventsOutput, _ bool) bool {
-		events = append(events, p.StackEvents...)
-		return true
-	}
-	if err := c.cloudformationAPI.DescribeStackEventsPages(input, pager); err != nil {
+	stackEvents, err := c.cloudformationAPI.DescribeStackEvents(ctx, input)
+	if err != nil {
 		return nil, errors.Wrapf(err, "describing CloudFormation stack %q events", *i.StackName)
 	}
 
-	return events, nil
+	return stackEvents.StackEvents, nil
 }
 
-// LookupCloudTrailEvents looks up stack events in CloudTrail
-func (c *StackCollection) LookupCloudTrailEvents(ctx context.Context, i *Stack) ([]types.Event, error) {
+func (c *StackCollection) LookupCloudTrailEvents(ctx context.Context, i *Stack) ([]cttypes.Event, error) {
 	input := &cloudtrail.LookupEventsInput{
-		LookupAttributes: []types.LookupAttribute{{
-			AttributeKey:   types.LookupAttributeKeyResourceName,
+		LookupAttributes: []cttypes.LookupAttribute{{
+			AttributeKey:   cttypes.LookupAttributeKeyResourceName,
 			AttributeValue: i.StackId,
 		}},
 	}
 
-	var events []types.Event
+	var events []cttypes.Event
 	paginator := cloudtrail.NewLookupEventsPaginator(c.cloudTrailAPI, input)
 	for paginator.HasMorePages() {
 		out, err := paginator.NextPage(ctx)
@@ -630,8 +726,8 @@ func (c *StackCollection) LookupCloudTrailEvents(ctx context.Context, i *Stack)
 	return events, nil
 }
 
-func (c *StackCollection) doCreateChangeSetRequest(stackName, changeSetName, description string, templateData TemplateData,
-	parameters map[string]string, capabilities []*string, tags []*cloudformation.Tag) error {
+func (c *StackCollection) doCreateChangeSetRequest(ctx context.Context, stackName, changeSetName, description string, templateData TemplateData,
+	parameters map[string]string, capabilities []types.Capability, tags []types.Tag) error {
 	input := &cloudformation.CreateChangeSetInput{
 		StackName:     &stackName,
 		ChangeSetName: &changeSetName,
@@ -639,24 +735,24 @@ func (c *StackCollection) doCreateChangeSetRequest(stackName, changeSetName, des
 		Tags:          append(tags, c.sharedTags...),
 	}
 
-	input.SetChangeSetType(cloudformation.ChangeSetTypeUpdate)
+	input.ChangeSetType = types.ChangeSetTypeUpdate
 
 	switch data := templateData.(type) {
 	case TemplateBody:
-		input.SetTemplateBody(string(data))
+		input.TemplateBody = aws.String(string(data))
 	case TemplateURL:
-		input.SetTemplateURL(string(data))
+		input.TemplateURL = aws.String(string(data))
 	default:
 		return fmt.Errorf("unknown template data type: %T", templateData)
 	}
 
-	input.SetCapabilities(capabilities)
+	input.Capabilities = capabilities
 	if cfnRole := c.roleARN; cfnRole != "" {
-		input.SetRoleARN(cfnRole)
+		input.RoleARN = &cfnRole
 	}
 
 	for k, v := range parameters {
-		p := &cloudformation.Parameter{
+		p := types.Parameter{
 			ParameterKey:   aws.String(k),
 			ParameterValue: aws.String(v),
 		}
@@ -664,7 +760,7 @@ func (c *StackCollection) doCreateChangeSetRequest(stackName, changeSetName, des
 	}
 
 	logger.Debug("creating changeSet, input = %#v", input)
-	s, err := c.cloudformationAPI.CreateChangeSet(input)
+	s, err := c.cloudformationAPI.CreateChangeSet(ctx, input)
 	if err != nil {
 		return errors.Wrapf(err, "creating ChangeSet %q for stack %q", changeSetName, stackName)
 	}
@@ -672,7 +768,7 @@ func (c *StackCollection) doCreateChangeSetRequest(stackName, changeSetName, des
 	return nil
 }
 
-func (c *StackCollection) doExecuteChangeSet(stackName string, changeSetName string) error {
+func (c *StackCollection) doExecuteChangeSet(ctx context.Context, stackName string, changeSetName string) error {
 	input := &cloudformation.ExecuteChangeSetInput{
 		ChangeSetName: &changeSetName,
 		StackName:     &stackName,
@@ -680,14 +776,14 @@ func (c *StackCollection) doExecuteChangeSet(stackName string, changeSetName str
 
 	logger.Debug("executing changeSet, input = %#v", input)
 
-	if _, err := c.cloudformationAPI.ExecuteChangeSet(input); err != nil {
+	if _, err := c.cloudformationAPI.ExecuteChangeSet(ctx, input); err != nil {
 		return errors.Wrapf(err, "executing CloudFormation ChangeSet %q for stack %q", changeSetName, stackName)
 	}
 	return nil
 }
 
 // DescribeStackChangeSet describes a ChangeSet by name
-func (c *StackCollection) DescribeStackChangeSet(i *Stack, changeSetName string) (*ChangeSet, error) {
+func (c *StackCollection) DescribeStackChangeSet(ctx context.Context, i *Stack, changeSetName string) (*ChangeSet, error) {
 	input := &cloudformation.DescribeChangeSetInput{
 		StackName:     i.StackName,
 		ChangeSetName: &changeSetName,
@@ -695,7 +791,7 @@ func (c *StackCollection) DescribeStackChangeSet(i *Stack, changeSetName string)
 	if api.IsSetAndNonEmptyString(i.StackId) {
 		input.StackName = i.StackId
 	}
-	resp, err := c.cloudformationAPI.DescribeChangeSet(input)
+	resp, err := c.cloudformationAPI.DescribeChangeSet(ctx, input)
 	if err != nil {
 		return nil, errors.Wrapf(err, "describing CloudFormation ChangeSet %s for stack %s", changeSetName, *i.StackName)
 	}
