@@ -1,6 +1,8 @@
 package unset
 
 import (
+	"context"
+
 	"github.com/kris-nova/logger"
 	"github.com/spf13/cobra"
 	"github.com/spf13/pflag"
@@ -64,7 +66,7 @@ func unsetLabels(cmd *cmdutils.Cmd, nodeGroupName string, removeLabels []string)
 	logger.Info("removing label(s) from nodegroup %s in cluster %s", nodeGroupName, cmd.ClusterConfig.Metadata)
 	service := managed.NewService(ctl.Provider.EKS(), ctl.Provider.EC2(), manager.NewStackCollection(ctl.Provider, cfg), cfg.Metadata.Name)
 	manager := label.New(cfg.Metadata.Name, service, ctl.Provider.EKS())
-	if err := manager.Unset(nodeGroupName, removeLabels); err != nil {
+	if err := manager.Unset(context.TODO(), nodeGroupName, removeLabels); err != nil {
 		return err
 	}
 
