@@ -1,11 +1,12 @@
 package fargate_test
 
 import (
+	"context"
 	"fmt"
 	"time"
 
+	"github.com/aws/aws-sdk-go-v2/service/cloudformation/types"
 	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/service/cloudformation"
 	"github.com/aws/aws-sdk-go/service/eks"
 	. "github.com/onsi/ginkgo"
 	. "github.com/onsi/gomega"
@@ -133,7 +134,7 @@ var _ = Describe("fargate", func() {
 			It("fails fast if the provided profile name is empty", func() {
 				client := fargate.NewWithRetryPolicy(clusterName, &mocks.EKSAPI{}, &retryPolicy, neverCalledStackManager)
 				waitForDeletion := false
-				err := client.DeleteProfile("", waitForDeletion)
+				err := client.DeleteProfile(context.TODO(), "", waitForDeletion)
 				Expect(err).To(HaveOccurred())
 				Expect(err.Error()).To(Equal("invalid Fargate profile name: empty"))
 			})
@@ -142,30 +143,31 @@ var _ = Describe("fargate", func() {
 				profileName := "test-green"
 				client := fargate.NewWithRetryPolicy(clusterName, mockForDeleteFargateProfile(profileName), &retryPolicy, neverCalledStackManager)
 				waitForDeletion := false
-				err := client.DeleteProfile(profileName, waitForDeletion)
+				err := client.DeleteProfile(context.TODO(), profileName, waitForDeletion)
 				Expect(err).To(Not(HaveOccurred()))
 			})
 
 			It("deletes the stack when no fargate profiles remain", func() {
 				fakeStackManager := new(fakes.FakeStackManager)
-				fakeStackManager.GetFargateStackReturns(&cloudformation.Stack{
+				fakeStackManager.GetFargateStackReturns(&types.Stack{
 					StackName: aws.String("my-fargate-profile"),
 				}, nil)
 				profileName := "test-green"
 				client := fargate.NewWithRetryPolicy(clusterName, mockForDeleteFargateProfileWithoutAnyRemaining(profileName), &retryPolicy, fakeStackManager)
 				waitForDeletion := false
-				err := client.DeleteProfile(profileName, waitForDeletion)
+				err := client.DeleteProfile(context.TODO(), profileName, waitForDeletion)
 				Expect(err).To(Not(HaveOccurred()))
 				Expect(fakeStackManager.GetFargateStackCallCount()).To(Equal(1))
 				Expect(fakeStackManager.DeleteStackBySpecCallCount()).To(Equal(1))
-				Expect(*fakeStackManager.DeleteStackBySpecArgsForCall(0).StackName).To(Equal("my-fargate-profile"))
+				_, stack := fakeStackManager.DeleteStackBySpecArgsForCall(0)
+				Expect(*stack.StackName).To(Equal("my-fargate-profile"))
 			})
 
 			It("fails by wrapping the root error with some additional context for clarity", func() {
 				profileName := "test-green"
 				client := fargate.NewWithRetryPolicy(clusterName, mockForFailureOnDeleteFargateProfile(profileName), &retryPolicy, neverCalledStackManager)
 				waitForDeletion := false
-				err := client.DeleteProfile(profileName, waitForDeletion)
+				err := client.DeleteProfile(context.TODO(), profileName, waitForDeletion)
 				Expect(err).To(HaveOccurred())
 				Expect(err.Error()).To(Equal("failed to delete Fargate profile \"test-green\": the Internet broke down"))
 			})
@@ -179,7 +181,7 @@ var _ = Describe("fargate", func() {
 				numRetriesBeforeDeletion := 3 // < MaxRetries
 				client := fargate.NewWithRetryPolicy(clusterName, mockForDeleteFargateProfileWithWait(profileName, numRetriesBeforeDeletion), retryPolicy, nil)
 				waitForDeletion := true
-				err := client.DeleteProfile(profileName, waitForDeletion)
+				err := client.DeleteProfile(context.TODO(), profileName, waitForDeletion)
 				Expect(err).To(Not(HaveOccurred()))
 			})
 
@@ -192,7 +194,7 @@ var _ = Describe("fargate", func() {
 				numRetriesBeforeDeletion := 5 // == MaxRetries, i.e. we will time out.
 				client := fargate.NewWithRetryPolicy(clusterName, mockForDeleteFargateProfileWithWait(profileName, numRetriesBeforeDeletion), retryPolicy, nil)
 				waitForDeletion := true
-				err := client.DeleteProfile(profileName, waitForDeletion)
+				err := client.DeleteProfile(context.TODO(), profileName, waitForDeletion)
 				Expect(err).To(HaveOccurred())
 				Expect(err.Error()).To(Equal("timed out while waiting for Fargate profile \"test-green\"'s deletion"))
 			})
