@@ -1,6 +1,7 @@
 package managed
 
 import (
+	"context"
 	"fmt"
 
 	"github.com/weaveworks/eksctl/pkg/awsapi"
@@ -78,8 +79,8 @@ func (m *Service) GetHealth(nodeGroupName string) ([]HealthIssue, error) {
 }
 
 // UpdateLabels adds or removes labels for a nodegroup
-func (m *Service) UpdateLabels(nodeGroupName string, labelsToAdd map[string]string, labelsToRemove []string) error {
-	template, err := m.stackCollection.GetManagedNodeGroupTemplate(manager.GetNodegroupOption{
+func (m *Service) UpdateLabels(ctx context.Context, nodeGroupName string, labelsToAdd map[string]string, labelsToRemove []string) error {
+	template, err := m.stackCollection.GetManagedNodeGroupTemplate(ctx, manager.GetNodegroupOption{
 		NodeGroupName: nodeGroupName,
 	})
 	if err != nil {
@@ -104,12 +105,12 @@ func (m *Service) UpdateLabels(nodeGroupName string, labelsToAdd map[string]stri
 		return err
 	}
 
-	return m.stackCollection.UpdateNodeGroupStack(nodeGroupName, template, true)
+	return m.stackCollection.UpdateNodeGroupStack(ctx, nodeGroupName, template, true)
 }
 
 // GetLabels fetches the labels for a nodegroup
-func (m *Service) GetLabels(nodeGroupName string) (map[string]string, error) {
-	template, err := m.stackCollection.GetManagedNodeGroupTemplate(manager.GetNodegroupOption{
+func (m *Service) GetLabels(ctx context.Context, nodeGroupName string) (map[string]string, error) {
+	template, err := m.stackCollection.GetManagedNodeGroupTemplate(ctx, manager.GetNodegroupOption{
 		NodeGroupName: nodeGroupName,
 	})
 	if err != nil {
